@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.10 2007/01/06 14:23:05 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.11 2007/01/15 15:55:12 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -53,7 +53,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.10 2007/01/06 14:23:05 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.11 2007/01/15 15:55:12 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -64,7 +64,7 @@ class SyL_ErrorWeb extends SyL_Error
      * @access public
      * @param object ǡ֥
      */
-    function errorHandler(&$dm)
+    function errorHandler()
     {
         // Хåե󥰥ꥢ
         // ɬ
