@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.7 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.8 2007/01/15 15:55:12 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -62,7 +62,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.7 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.8 2007/01/15 15:55:12 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
@@ -93,9 +93,9 @@ class SyL_RouterPathinfo extends SyL_Router
         } else {
             $pathinfo_dir = dirname($pathinfo);
             if ($pathinfo_dir == '/') {
-                $this->action_file = DIRECTORY_SEPARATOR . $script_name;
+                $this->action_file = '/' . $script_name;
             } else {
-                $this->action_file = $pathinfo_dir . DIRECTORY_SEPARATOR . $script_name;
+                $this->action_file = $pathinfo_dir . '/' . $script_name;
             }
             if ($this->ext) {
                 if (preg_match( '/^(.*)\/(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo, $matches)) {
