@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.7 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.8 2007/01/15 15:55:12 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -62,7 +62,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.7 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.8 2007/01/15 15:55:12 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo2 extends SyL_Router
@@ -105,7 +105,7 @@ class SyL_RouterPathinfo2 extends SyL_Router
             $pathinfo_dir   = dirname($pathinfo);
             $pathinfo_files = explode($this->action_delimiter, $pathinfo_file, 2);
             if ($pathinfo_dir != '/') {
-                $pathinfo_dir = $pathinfo_dir . DIRECTORY_SEPARATOR;
+                $pathinfo_dir = $pathinfo_dir . '/';
             }
             if (count($pathinfo_files) == 2) {
                 if (($this->action_delimiter == '.') && ($this->url_ext == ('.' . $pathinfo_files[1]))) {
