@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataManager.php,v 1.4 2007/01/06 14:23:05 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataManager.php,v 1.5 2007/01/15 15:55:12 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_ComponentMethod.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataManager.php,v 1.4 2007/01/06 14:23:05 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataManager.php,v 1.5 2007/01/15 15:55:12 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataManager
@@ -204,14 +204,12 @@ class SyL_DataManager
     {
         $template_dir  = $this->getTemplateDir();
         $template_file = $this->convertPath($this->template_file, false);
-        $real_path     = realpath($template_dir . $template_file);
-        $reg           = '/^' . preg_quote($template_dir, '/') . '/';
 
         // ǥХå - ƥץ졼Ȥξ
         SyL_Loggers::debug("[DataManager] template info  dir: {$template_dir} file: {$template_file}");
 
-        // ե¸ߥå
-        if (!preg_match($reg, $real_path)) {
+        // ƥץ졼ȥե¸ߥå
+        if (!is_file($template_dir . $template_file)) {
             SyL_Response::redirect404();
         }
         return $template_file;
@@ -252,8 +250,10 @@ class SyL_DataManager
     {
         if ($is_dir_path && !preg_match('/(\\\\|\/)$/', $path)) {
             $path .= '/';
-        } else if (!$is_dir_path && preg_match('/^(\\\\|\/)/', $path)) {
-            $path = substr($path, 1);
+        } else if (!$is_dir_path) {
+            while (preg_match('/^(\\\\|\/)/', $path)) {
+                $path = substr($path, 1);
+            }
         }
         return $path;
     }
