@@ -27,12 +27,17 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailSendmail.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailSendmail.php,v 1.8 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-define('SYL_MAIL_SENDMAIL_PATH', '/usr/lib/sendmail');
+/**
+ * sendmailޥ
+ */
+if (!defined('SYL_MAIL_TYPE')) {
+    define('SYL_MAIL_TYPE', 'Sendmail:/usr/lib/sendmail');
+}
 
 /**
  *  Sendmail᡼饹
@@ -41,7 +46,7 @@ define('SYL_MAIL_SENDMAIL_PATH', '/usr/lib/sendmail');
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_MailSendmail.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_MailSendmail.php,v 1.8 2007/01/06 14:23:05 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_MailSendmail extends SyL_Mail
@@ -52,7 +57,7 @@ class SyL_MailSendmail extends SyL_Mail
      * @access private
      * @var string
      */
-    var $sendmail_path = SYL_MAIL_SENDMAIL_PATH;
+    var $sendmail_path = '';
 
     /**
      * 󥹥ȥ饯
@@ -61,6 +66,8 @@ class SyL_MailSendmail extends SyL_Mail
      */
     function SyL_MailSendmail()
     {
+        $tmp = explode(':', SYL_MAIL_TYPE, 2);
+        $this->sendmail_path = (strtolower($tmp[0]) == 'sendmail') ? $tmp[1] : $tmp[0];
         parent::SyL_Mail();
     }
 
@@ -81,17 +88,15 @@ class SyL_MailSendmail extends SyL_Mail
      * @access public
      * @param array ᡼°
      * @param bool ե饰
-     * @return OK: true, NG: false
      */
-    function init($attributes=array(), $all=false)
+    function init($attributes=array())
     {
         $attributes = array_change_key_case($attributes, CASE_LOWER);
-        parent::init($attributes, $all);
+        parent::init($attributes);
         // Sendmailѥ
         if (isset($attributes['sendmail'])) {
             $this->sendmail_path = $attributes['sendmail'];
         }
-        return true;
     }
 
     /**
@@ -102,7 +107,14 @@ class SyL_MailSendmail extends SyL_Mail
      */
     function send()
     {
-        if (!parent::send()) {
+        // Fromɬ
+        if ($this->headers['MAIL_FROM'] == '') {
+            $this->error_message = "[SyL error] From Address not found";
+            return false;
+        }
+        // Toɬ
+        if (count($this->headers['To']) == 0) {
+            $this->error_message = "[SyL error] To Address not found";
             return false;
         }
 
