@@ -6,7 +6,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: defaultcommand.php,v 1.3 2006/12/23 11:14:31 seasonstream Exp $
+ * @version   CVS: $Id: defaultcommand.php,v 1.4 2007/01/15 15:55:12 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class DefaultCommand
@@ -53,8 +53,8 @@ class DefaultCommand
         $file = basename($cmd->getArg(0));
         $help = <<<EOF
 Usage:
-  {$file} project [or pro] -d <dir> -w <name> [-c]
-  {$file} application [or app] -d <dir> -w <name> [-c]
+  {$file} project [or pro] -d <dir> -w <name> [-c <file>]
+  {$file} application [or app] -d <dir> -w <name> [-c <file>]
   {$file} controller [or con] -d <dir> -w <name> -c <file>
   {$file} action [or act] -d <dir> -w <name> -a <name>
   {$file} template [or tem] -d <dir> -w <name> -t <name>
@@ -87,7 +87,7 @@ EOF;
        // $php_version = PHP_SAPI;
         $version = <<<EOF
 {$file} - SyL {$this->version} (on PHP {$php_version} {$php_sapi} - {$php_os})
-Copyright (c) 2006 k.watanabe
+Copyright (c) 2006-2007 k.watanabe
 EOF;
         $cmd->stdout($version);
     }
